<?php
/** Papiamento (Papiamentu)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Delaraha (on pap.wikipedia.org)
 * @author Kamizu
 * @author Sdm1985
 * @author לערי ריינהארט
 */

$messages = array(
'underline-always' => 'Semper',
'underline-never'  => 'Niunka',

# Dates
'sunday'    => 'djadomingu',
'monday'    => 'djaluna',
'tuesday'   => 'djamars',
'wednesday' => 'djarason',
'thursday'  => 'djaweps',
'friday'    => 'djabièrne',
'saturday'  => 'djasabra',
'january'   => 'yanüari',
'february'  => 'febrüari',
'march'     => 'mart',
'april'     => 'aprel',
'may_long'  => 'mei',
'june'      => 'yüni',
'july'      => 'yüli',
'august'    => 'ougùstùs',
'september' => 'sèptèmber',
'october'   => 'òktober',
'november'  => 'novèmber',
'december'  => 'desèmber',
'jan'       => 'yan',
'feb'       => 'feb',
'mar'       => 'mrt',
'apr'       => 'apr',
'may'       => 'mei',
'jun'       => 'yün',
'jul'       => 'yül',
'aug'       => 'oug',
'sep'       => 'sep',
'oct'       => 'okt',
'nov'       => 'nov',
'dec'       => 'des',

# Categories related messages
'category_header' => 'Artíkulonan den kategoria "$1"',
'subcategories'   => 'Supkategorianan',

'about'         => 'Info',
'article'       => 'Artíkulo',
'cancel'        => 'Kanselá',
'moredotdotdot' => 'Mas...',
'mypage'        => 'Mi página',
'mytalk'        => 'Mi diskushon',
'anontalk'      => 'Diskushon pa e IP aki',
'navigation'    => 'Nabegashon',
'and'           => '&#32;i',

# Cologne Blue skin
'faq'     => 'Preguntanan mas Puntrá',
'faqpage' => 'Project:Preguntanan mas Puntrá',

'errorpagetitle'    => 'Eror',
'returnto'          => 'Bai bèk $1.',
'tagline'           => 'Di {{SITENAME}}',
'help'              => 'Ayudo',
'search'            => 'Buska',
'history'           => 'Historia di página',
'history_short'     => 'Historia',
'edit'              => 'Editá',
'editthispage'      => 'Editá e página aki',
'delete'            => 'Kita',
'protect'           => 'Protehá',
'unprotect'         => 'stop di protehá',
'unprotectthispage' => 'Stop di protehá e página aki',
'talkpagelinktext'  => 'Papia',
'specialpage'       => 'Página Spesial',
'personaltools'     => 'Hèrmèntnan Personal',
'postcomment'       => 'Sekshon Nobo',
'articlepage'       => 'Wak página di kontenido',
'talk'              => 'Diskushon',
'views'             => 'Kantidat di biaha mirá',
'toolbox'           => 'Kaha di Hèrmènt',
'userpage'          => 'Wak página di uzadó',
'projectpage'       => 'Wak página di e proyekto',
'imagepage'         => 'Mira página di e dokumento',
'mediawikipage'     => 'Mira paginanan di mensahe',
'templatepage'      => 'Mira malchi di e página',
'viewhelppage'      => 'Mira página di yudansa',
'categorypage'      => 'Mira e página di kategoria',
'viewtalkpage'      => 'Wak diskushon',
'otherlanguages'    => 'Na otro idioma',
'redirectedfrom'    => '(Bo a yega akinan pa via di e página $1)',
'redirectpagesub'   => 'Página ku ta sirbi komo portal',
'lastmodifiedat'    => 'E páginá aki a wòrdu kambiá ultimo biaha riba $1, ora $2.',
'viewcount'         => 'E paginá aki a wòrdu mirá {{PLURAL:$1|biaha|$1 biaha}}.',
'protectedpage'     => 'Página Protehá',
'jumpto'            => 'Bai na:',
'jumptonavigation'  => 'Nabegashon',
'jumptosearch'      => 'Buska',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Tokante {{SITENAME}}',
'aboutpage'            => 'Project:Info',
'copyright'            => 'E kontenido ta disponibel bou di $1.',
'copyrightpage'        => '{{ns:project}}:Derechinan di outor',
'currentevents'        => 'Eventonan aktual',
'currentevents-url'    => 'Project:Eventonan aktual',
'disclaimers'          => 'Deklarashon di Liberashon for di Responsabilidatnan',
'disclaimerpage'       => 'Project:Deklarashon di Liberashon for di Responsabilidat General',
'edithelp'             => 'Ayudo ku editamentu',
'edithelppage'         => 'Help:Kon pa editá artíkulo',
'helppage'             => 'Help:Kontenido',
'mainpage'             => 'Página Prinsipal',
'mainpage-description' => 'Página Prinsipal',
'policy-url'           => 'Project:Pólisa',
'portal'               => 'Portal di komunidat',
'portal-url'           => 'Project:Portal di komunidat',
'privacy'              => 'Pólisa di Privasidat',
'privacypage'          => 'Project:Pólisa di Privasidat',

'badaccess'        => 'Eror di outorisashon',
'badaccess-group0' => 'Bo no tin outorisashon pa ehekutá e akshon ku bo a skohe.',

'youhavenewmessages'      => 'Bo tin $1 ($2).',
'newmessageslink'         => 'mensahe nobo',
'youhavenewmessagesmulti' => 'Bo tin mensahe nobo riba $1',
'editsection'             => 'editá',
'toc'                     => 'Kontenido',
'showtoc'                 => 'mustra',
'hidetoc'                 => 'skonde',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Artíkulo',
'nstab-user'      => 'Página personal',
'nstab-media'     => 'Media',
'nstab-special'   => 'Spesial',
'nstab-image'     => 'Imagen',
'nstab-mediawiki' => 'Mensahe',
'nstab-template'  => 'Predefinishon',
'nstab-help'      => 'Ayudo',
'nstab-category'  => 'Kategoria',

# Main script and global functions
'nosuchspecialpage' => 'E página spesial no ta eksistí',
'nospecialpagetext' => '<strong>Bo a pidi un página spesial inválido.</strong>

Bo por haña un lista di tur [[Special:SpecialPages|{{int:specialpages}}]].',

# General errors
'error'         => 'Eror',
'internalerror' => 'Eror interno',
'cannotdelete'  => 'No por a kita e página òf imagen spesifiká. (Por ta e kaso ku un otro hende a kita e kaba.)',
'badtitle'      => 'Título inválido',
'badtitletext'  => 'E título di e página ku bo a pidi tabata inválido, bashí, òf un link pa un inter-idioma òf inter-wiki inkorekto.',
'viewsource'    => 'Wak fuente',

# Login and logout pages
'welcomecreation'            => '== Bon bini, $1! ==
Bo kuenta ta trahá.
No lubidá di kambia bo [[Special:Preferences|{{SITENAME}} preferensianan]].',
'yourname'                   => 'Nòmber di uzadó',
'yourpassword'               => 'Kontraseña',
'yourpasswordagain'          => 'Hinka kontraseña atrobe',
'remembermypassword'         => 'Kordá mi (for a maximum of $1 {{PLURAL:$1|day|days}})',
'userlogin'                  => 'Traha un kuenta nobo òf outentiká',
'userlogout'                 => 'Terminá sesion',
'badretype'                  => 'E kontraseñanan hinká no ta kuadra.',
'wrongpassword'              => 'Kontraseña no ta korekto. Por fabor purba atrobe.',
'wrongpasswordempty'         => 'Kontraseña tabata bashí. Por fabor purba atrobe.',
'acct_creation_throttle_hit' => 'Bishitantenan na uzando bo IP adrès a traha $1 kuenta den e último 24 ora, lokual ta e máksimo permití den e periodo aki. Esaki ta nifiká ku hendenan uzando e IP adrès aki no por traha mas kuenta na e momentu aki.',
'emailauthenticated'         => 'Bo e-mail adrès tabata outentiká riba $1.',
'emailnotauthenticated'      => 'Bo e-mail adrès no ta outentiká ahinda. Lo siguiente funkshonnan lo no ta disponibel.',
'emailconfirmlink'           => 'Konfirmá bo e-mail adrès.',
'accountcreated'             => 'Kuenta trahá',
'accountcreatedtext'         => 'E kuenta di uzadó pa $1 tabata trahá.',

# Edit pages
'watchthis'        => 'Observá e página aki',
'anoneditwarning'  => 'Bo no a outentiká bo mes.
Bo por kambia página libremente, pero tene kuenta ku lo nota bo IP adrès den e historia di kambionan hasí na e página aki.',
'blockedtitle'     => 'Uzadó ta blokiá',
'confirmedittext'  => 'Bo mester konfirmá bo e-mail adrès promé ku bo editá página. Por fabor duna i validá bo e-mail adrès via bo [[Special:Preferences|preferensianan]].',
'accmailtitle'     => 'Kontraseña mandá.',
'accmailtext'      => "E kontraseña pa '$1' tabata mandá pa $2.",
'newarticle'       => '(Nobo)',
'anontalkpagetext' => "----''Esaki ta e página di diskushon pa un uzadó anonimo ku no a traha un kuenta ahinda, òf no sa uza e. Ta pa e rason aki nos tin ku uza IP adrès pa identifiká e persona. Diferente uzadó por uza e IP adrès aki. Si bo ta un uzadó anonimo i ta sinti ku komentario irelevante tabata mandá pa bo, por fabor [[Special:UserLogin|registrá un kuenta nobo òf outentiká bo mes]] pa evitá konfushon den futuro.''",
'yourtext'         => 'Bo teksto',
'yourdiff'         => 'Diferensianan',

# History pages
'currentrev'          => 'Revishon aktual',
'currentrevisionlink' => 'wak revishon aktual',
'cur'                 => 'akt',
'next'                => 'siguiente',
'last'                => 'prev',
'histlegend'          => 'Leyenda: (akt) = diferensia ku vershon aktual,
(prev) = diferensia ku vershon previo, m = editashon menor',
'histfirst'           => 'Promé',
'histlast'            => 'Último',

# Search results
'nextn'          => 'siguiente {{PLURAL:$1|$1}}',
'searchhelp-url' => 'Help:Kontenido',

# Preferences page
'preferences'    => 'Preferensianan',
'mypreferences'  => 'Mi preferensianan',
'changepassword' => 'Kambia kontraseña',
'timezonelegend' => 'Zona di tempu',
'allowemail'     => 'Akseptá e-mail di otro uzadó',
'youremail'      => 'E-mail:',
'username'       => 'Nòmber di uzadó:',
'uid'            => 'ID di uzadó:',
'yourrealname'   => 'Nòmber berdadero:',
'yourlanguage'   => 'Idioma:',
'yourvariant'    => 'Variante:',
'yournick'       => 'Nòmber di kariño:',
'badsig'         => 'Firma inválido; kontrolá e HTML uzá.',

# Recent changes
'recentchanges'     => 'Kambionan resien',
'recentchangestext' => 'Sigui e kambionan mas resien na {{SITENAME}} riba e página aki.',
'rclistfrom'        => 'Mustra kambionan nobo kuminsando for di $1',
'rcshowhideminor'   => '$1 kambionan menor',
'rcshowhidebots'    => '$1 botnan',
'rcshowhideanons'   => '$1 uzadónan anonimo',
'rclinks'           => 'Mustra último $1 kambionan den último $2 dianan<br />$3',
'hide'              => 'Skonde',
'show'              => 'Mustra',

# File description page
'file-anchor-link' => 'Imagen',

# Unwatched pages
'unwatchedpages' => 'Páginanan no observá',

# Statistics
'statistics'              => 'Estadístika',
'statistics-header-users' => 'Estadístika di uzadónan',

# Miscellaneous special pages
'ncategories'             => '$1 {{PLURAL:$1|kategoria|kategorianan}}',
'uncategorizedpages'      => 'Páginanan no kategorisá',
'uncategorizedcategories' => 'Kategorianan no kategorisá',
'unusedcategories'        => 'Kategorianan no uzá',
'wantedcategories'        => 'Kategorianan deseá',
'wantedpages'             => 'Páginanan deseá',
'ancientpages'            => 'Páginanan mas bieu',
'unusedcategoriestext'    => 'E siguiente kategorianan ta eksistí pero ningun artíkulo òf kategoria ta hasi uzo di nan.',

# Special:Log
'alllogstext' => 'Esaki ta un bista kombiná di registronan.
Bo por skohe un tipo di registro tambe, òf filtrá e bista ku un nòmber di uzadó òf un título di un artíkulo.',

# Special:AllPages
'allpages'          => 'Tur página',
'alphaindexline'    => '$1 pa $2',
'allpagesfrom'      => 'Mustra páginanan kuminsando na:',
'allarticles'       => 'Tur artíkulo',
'allinnamespace'    => 'Tur página (dominio $1)',
'allnotinnamespace' => 'Tur página (no den dominio di $1)',
'allpagesprev'      => 'Anterior',
'allpagesnext'      => 'Siguiente',
'allpagesprefix'    => 'Mustra páginanan kuminsando ku e prefiho:',

# Special:Categories
'categories'         => 'Kategorianan',
'categoriespagetext' => 'Esaki ta e kategorianan ku ta eksistí den {{SITENAME}}.
[[Special:UnusedCategories|Unused categories]] are not shown here.
Also see [[Special:WantedCategories|wanted categories]].',

# E-mail user
'emailuser'       => 'Manda e-mail pa e uzadó aki',
'emailpage'       => 'Manda e-mail',
'emailpagetext'   => 'E formulario aki lo manda un e-mail pa e uzadò aki.
Bo e-mail adrès (manera ta pará den bo preferensianan) lo aparesé den e e-mail pa e resipiente por respondé na bo direktamente.',
'defemailsubject' => 'E-mail di {{SITENAME}}',
'emailfrom'       => 'Di:',
'emailto'         => 'Pa:',
'emailsubject'    => 'Tópiko:',
'emailmessage'    => 'Mensahe:',
'emailsend'       => 'Manda',
'emailsent'       => 'E-mail mandá',
'emailsenttext'   => 'Bo e-mail tabata mandá.',

# Watchlist
'watchlist'         => 'Mi lista di observashon',
'nowatchlist'       => 'Bo lista di observashon ta bashí.',
'watchnologintext'  => 'Bo mester [[Special:UserLogin|outentiká bo mes]] pa modifiká bo lista di observashon.',
'addedwatchtext'    => "E página \"[[:\$1]]\" tabata añadí na bo [[Special:Watchlist|lista di observashon]].
Lo lista kambionan hasí na e página aki i su página di diskushon einan,
i e página lo aparesé '''vet''' den e [[Special:RecentChanges|lista di kambionan resien]] pa
e ta mas fásil pa bo mira.

Si despues bo ke kita e página for di bo lista di observashon, primi \"Stop di observá\" den e menú ariba.",
'watch'             => 'Observá',
'watchthispage'     => 'Observá e página aki',
'unwatch'           => 'Stop di observá',
'unwatchthispage'   => 'Stop di observá',
'watchlistcontains' => 'Bo lista di observashon tin $1 {{PLURAL:$1|página|páginanan}}.',
'wlshowlast'        => 'Mustra último $1 oranan $2 dianan $3',

'changed' => 'kambiá',
'created' => 'trahá',

# Delete
'confirm'        => 'Konfirmá',
'actioncomplete' => 'Akshon kompletá',

# Protect
'prot_1movedto2' => '[[$1]] mové pa [[$2]]',
'protect-legend' => 'Konfirmá protekshon',

# Undelete
'undelete' => 'Wak páginanan kitá',

# Namespace form on various pages
'invert'         => 'Invertí selekshon',
'blanknamespace' => '(Prinsipal)',

# Contributions
'contributions' => 'Kontribushonnan di uzadó',
'mycontris'     => 'Mi kontribushonnan',

# What links here
'whatlinkshere' => 'Kiko ta link aki',

# Block/unblock
'blockip'            => 'Blokia uzadó',
'badipaddress'       => 'IP adrès ta inválido',
'blockipsuccesssub'  => 'Blokeo eksitoso',
'blockipsuccesstext' => '[[Special:Contributions/$1|$1]] tabata blokiá.<br />
Wak e [[Special:BlockList|lista di blokeonan]] pa wak tur blokeo aktivo.',
'unblockip'          => 'Desblokia uzadó',
'blocklink'          => 'blokia',
'unblocklink'        => 'desblokia',
'contribslink'       => "kontrib'nan",
'autoblocker'        => 'Bo tabata outomatikamente blokiá pasombra "[[User:$1|$1]]" a uza e IP adrès aki resientemente. E rason ku $1 tabata blokiá ta: "\'\'\'$2\'\'\'"',
'unblocklogentry'    => 'a desblokia $1',

# Move page
'articleexists' => 'Tin un página ku e título ei kaba, òf e
título ku bo a skohe no ta válido.
Por fabor skohe un otro título.',

# Namespace 8 related
'allmessages'        => 'Mensahenan di sistema',
'allmessagesname'    => 'Nòmber',
'allmessagesdefault' => 'Teksto predeterminá',
'allmessagescurrent' => 'Teksto aktual',
'allmessagestext'    => 'Esaki ta un lista di mensahe di sistema disponibel den e dominio di MediaWiki.',

# Attribution
'anonymous' => 'Uzadó(nan) anonimo di {{SITENAME}}',

# Browsing diffs
'previousdiff' => '← Diferensia anterior',
'nextdiff'     => 'Siguiente diferensia →',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'tur',
'namespacesall' => 'tur',

# E-mail address confirmation
'confirmemail'           => 'Konfirmá e-mail adrès',
'confirmemail_text'      => 'Bo mester validá bo e-mail adrès pa uza funkshonnan di e-mail.
Primi e boton abou pa manda un e-mail di konfirmashon pa bo e-mail adrès.
Ora bo haña e e-mail, bo ta sigui e instrukshonnan aden.
Pa kontrolá si bo ta konfirmá kaba, wak bo preferensianan.',
'confirmemail_send'      => 'Manda un kódigo di konfirmashon via e-mail.',
'confirmemail_sent'      => 'E-mail pa konfirmashon mandá.',
'confirmemail_invalid'   => 'Kódigo di konfirmashon inválido. Ta posibel ku e kódigo a kaduká.',
'confirmemail_needlogin' => 'Bo mester $1 pa konfirmá bo e-mail adrès.',
'confirmemail_success'   => 'Bo e-mail adrès tabata konfirmá. Bo por outentiká bo mes i gosa di {{SITENAME}}.',
'confirmemail_loggedin'  => 'Bo e-mail adrès ta konfirmá.',
'confirmemail_subject'   => '{{SITENAME}}: Konfirmashon di e-mail adrès',
'confirmemail_body'      => 'Un hende, probablemente abo, di IP adrès $1, a registrá e
kuenta "$2" ku e e-mail adrès aki riba {{SITENAME}}.

Pa konfirmá ku e kuenta aki en berdat ta di bo i pa aktivá
funkshonnan di e-mail riba {{SITENAME}}, por fabor habri e link aki:

$3

Si esaki *no* ta abo, por fabor no habri e link.
Follow this link to cancel the e-mail address confirmation:

$5

E kódigo di konfirmashon aki lo kaduká riba $4.',

# Delete conflict
'confirmrecreate' => "[[User:$1|$1]] ([[User talk:$1|diskushon]]) a kita e artíkulo aki despues ku bo ta kuminsá editá. E rason ta:
: ''$2''
Por fabor konfirmá ku bo ke traha e artíkulo aki di nobo.",

# Special:SpecialPages
'specialpages' => 'Páginanan Spesial',

);
